# Generated by Django 5.0.3 on 2024-03-16 15:39

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Config",
            fields=[
                (
                    "key",
                    models.SlugField(max_length=128, primary_key=True, serialize=False),
                ),
                ("value", models.TextField(blank=True, null=True)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("T", "Text"),
                            ("B", "Boolean"),
                            ("I", "Integer"),
                            ("F", "Float"),
                            ("D", "Date"),
                            ("M", "Datetime"),
                            ("A", "Array"),
                        ],
                        default="T",
                        max_length=1,
                    ),
                ),
            ],
        ),
    ]
